@@ -1,34 +1,27 @@
 package Firewall::Utils::Date;
 
-#------------------------------------------------------------------------------
-# 加载扩展插件
-#------------------------------------------------------------------------------
-use 5.016;
+use 5.018;
+use Carp;
 use Moose;
 use namespace::autoclean;
+use Mojo::Util qw(dumper);
 
-sub getLocalDate {
+sub getFormatedDate {
   my ( $self, @param ) = @_;
-  # 初始化变量
   my ( $format, $time );
-
   if ( defined $param[0] and $param[0] =~ /^\d+$/ ) {
     ( $time, $format ) = @param;
   }
   else {
     ( $format, $time ) = @param;
   }
-  # 缺省时间格式
   if ( not defined $format ) {
     $format = 'yyyy-mm-dd hh:mi:ss';
   }
-  # 缺省为本地时间
   if ( not defined $time ) {
     $time = time();
   }
-  # 时间对象切片
   my ( $sec, $min, $hour, $mday, $mon, $year ) = localtime($time);
-  # 定义本地时间数据字典
   my %timeMap = (
     yyyy => $year + 1900,
     mm   => $mon + 1,
@@ -48,14 +41,12 @@ sub getLocalDate {
   my $regex = '(' . join( '|', keys %timeMap ) . ')';
   my @times = map { $timeMap{$_} } ( $format =~ /$regex/g );
   if ( scalar(@times) == 0 ) {
-    confess "ERROR: format string [$format]  has none valid characters\n";
+    confess "ERROR: format string [$format]  has none valid charactors\n";
   }
   $format =~ s/$regex/$formatMap{$1}/g;
-  my $localTime = sprintf( "$format", @times );
-
-  # 返回计算结果
-  return $localTime;
-}
+  my $formatedTime = sprintf( "$format", @times );
+  return ($formatedTime);
+} ## end sub getFormatedDate
 
 __PACKAGE__->meta->make_immutable;
 1;
